@@ -9,6 +9,6 @@ def init(plugin_manager):
     import aj
     api.NetworkManager.any(aj.context)
 
-    from .aug import ResolvConfEndpoint
-    from .main import ItemProvider
-    from .views import Handler
+    from .aug import ResolvConfEndpoint # skipcq: PYL-W0611
+    from .main import ItemProvider # skipcq: PYL-W0611
+    from .views import Handler # skipcq: PYL-W0611
